@@ -257,6 +257,16 @@ def read_configuration(path):
     return configuration
 
 
+def __get_lambda_name(method_config):
+    lambda_build_name = method_config['x-amazon-apigateway-integration']['uri']['Fn::Join'][1][1]
+    case = {
+        "Fn::GetAtt": lambda x: x['Fn::GetAtt'][0],
+        "Fn::Sub": lambda x: x["Fn::Sub"].split(":")[-1].split("-")[-1],
+        "Fn::ImportValue": lambda x: x['Fn::ImportValue']["Fn::Sub"]
+    }
+    return case.get(list(lambda_build_name.items())[0], lambda x: x)(lambda_build_name)
+
+
 def process_api_paths(*, lambda_configuration, handler):
     if not lambda_configuration:
         return None
@@ -264,7 +274,7 @@ def process_api_paths(*, lambda_configuration, handler):
     all_endpoints = ''
     for path, v in lambda_configuration['swagger'].items():
         method = list(filter(lambda x: x != 'options', v))[0]
-        lambda_name = v[method]['x-amazon-apigateway-integration']['uri']['Fn::Join'][1][1]['Fn::GetAtt'][0]
+        lambda_name = __get_lambda_name(v[method])
         endpoint = EndpointConfiguration(path=path, method=method, name=lambda_name, parameters=v[method]['parameters'],
                                          handler=handler)
         all_endpoints += endpoint.synth()
